summaryrefslogtreecommitdiff
path: root/examples
diff options
context:
space:
mode:
authorschmidt <douglascraigschmidt@users.noreply.github.com>2001-07-22 13:41:44 +0000
committerschmidt <douglascraigschmidt@users.noreply.github.com>2001-07-22 13:41:44 +0000
commit7e239e593f52f0fb66aeed1ab486b830001cb1ef (patch)
tree47e98c5b24970c0045a5fc9ee31b2588f04c3438 /examples
parent57d0e57684c4357676f7d6e9c6be9ffec08b0f39 (diff)
downloadATCD-7e239e593f52f0fb66aeed1ab486b830001cb1ef.tar.gz
ChangeLogTag:Sun Jul 22 08:19:43 2001 Douglas C. Schmidt <schmidt@ace.cs.wustl.edu>
Diffstat (limited to 'examples')
-rw-r--r--examples/Connection/non_blocking/CPP-acceptor.cpp34
-rw-r--r--examples/Connection/non_blocking/CPP-connector.cpp32
-rw-r--r--examples/Service_Configurator/IPC-tests/server/Handle_Thr_Stream.cpp24
3 files changed, 45 insertions, 45 deletions
diff --git a/examples/Connection/non_blocking/CPP-connector.cpp b/examples/Connection/non_blocking/CPP-connector.cpp
index 04f9dacc5ce..af4bc3ab8dd 100644
--- a/examples/Connection/non_blocking/CPP-connector.cpp
+++ b/examples/Connection/non_blocking/CPP-connector.cpp
@@ -12,7 +12,7 @@ ACE_RCSID(non_blocking, CPP_connector, "$Id$")
#define PR_CO_1 ACE_PEER_CONNECTOR_1
#define PR_CO_2 ACE_PEER_CONNECTOR_2
#define PR_AD ACE_PEER_CONNECTOR_ADDR
-#define SH SVC_HANDLER
+#define SVH SVC_HANDLER
template <PR_ST_1>
Peer_Handler<PR_ST_2>::Peer_Handler (ACE_Reactor *r)
@@ -201,8 +201,8 @@ Peer_Handler<PR_ST_2>::handle_close (ACE_HANDLE h,
return 0;
}
-template <class SH, PR_CO_1> int
-IPC_Client<SH, PR_CO_2>::svc (void)
+template <class SVH, PR_CO_1> int
+IPC_Client<SVH, PR_CO_2>::svc (void)
{
if (this->reactor ())
ACE_Reactor::run_event_loop ();
@@ -210,20 +210,20 @@ IPC_Client<SH, PR_CO_2>::svc (void)
return 0;
}
-template <class SH, PR_CO_1> int
-IPC_Client<SH, PR_CO_2>::fini (void)
+template <class SVH, PR_CO_1> int
+IPC_Client<SVH, PR_CO_2>::fini (void)
{
return 0;
}
-template <class SH, PR_CO_1>
-IPC_Client<SH, PR_CO_2>::IPC_Client (void)
+template <class SVH, PR_CO_1>
+IPC_Client<SVH, PR_CO_2>::IPC_Client (void)
: done_handler_ (ACE_Sig_Handler_Ex (ACE_Reactor::end_event_loop))
{
}
-template <class SH, PR_CO_1> int
-IPC_Client<SH, PR_CO_2>::init (int argc, char *argv[])
+template <class SVH, PR_CO_1> int
+IPC_Client<SVH, PR_CO_2>::init (int argc, char *argv[])
{
// Call down to the CONNECTOR's open() method to do the
// initialization.
@@ -248,9 +248,9 @@ IPC_Client<SH, PR_CO_2>::init (int argc, char *argv[])
this->options_.set (ACE_Synch_Options::USE_REACTOR,
timeout);
- SH *sh;
+ SVH *sh;
ACE_NEW_RETURN (sh,
- SH (this->reactor ()),
+ SVH (this->reactor ()),
-1);
// Connect to the peer.
@@ -266,13 +266,13 @@ IPC_Client<SH, PR_CO_2>::init (int argc, char *argv[])
return 0;
}
-template <class SH, PR_CO_1>
-IPC_Client<SH, PR_CO_2>::~IPC_Client (void)
+template <class SVH, PR_CO_1>
+IPC_Client<SVH, PR_CO_2>::~IPC_Client (void)
{
}
-template <class SH, PR_CO_1> int
-IPC_Client<SH, PR_CO_2>::handle_close (ACE_HANDLE h,
+template <class SVH, PR_CO_1> int
+IPC_Client<SVH, PR_CO_2>::handle_close (ACE_HANDLE h,
ACE_Reactor_Mask)
{
if (h == ACE_INVALID_HANDLE)
@@ -297,5 +297,5 @@ IPC_Client<SH, PR_CO_2>::handle_close (ACE_HANDLE h,
#undef PR_CO_1
#undef PR_CO_2
#undef PR_AD
-#undef SH
+#undef SVH
#endif /* CPP_CONNECTOR_C */
diff --git a/examples/Service_Configurator/IPC-tests/server/Handle_Thr_Stream.cpp b/examples/Service_Configurator/IPC-tests/server/Handle_Thr_Stream.cpp
index 3a9da3d5f94..00c75f552bd 100644
--- a/examples/Service_Configurator/IPC-tests/server/Handle_Thr_Stream.cpp
+++ b/examples/Service_Configurator/IPC-tests/server/Handle_Thr_Stream.cpp
@@ -17,25 +17,25 @@ ACE_RCSID(server, Handle_Thr_Stream, "$Id$")
#endif /* __ACE_INLINE__ */
// Shorthand names.
-#define SH SVC_HANDLER
+#define SVH SVC_HANDLER
#define PR_AC_1 ACE_PEER_ACCEPTOR_1
#define PR_AC_2 ACE_PEER_ACCEPTOR_2
#define PR_ST_1 ACE_PEER_STREAM_1
#define PR_ST_2 ACE_PEER_STREAM_2
-template <class SH, PR_AC_1>
-Handle_Thr_Acceptor<SH, PR_AC_2>::~Handle_Thr_Acceptor (void)
+template <class SVH, PR_AC_1>
+Handle_Thr_Acceptor<SVH, PR_AC_2>::~Handle_Thr_Acceptor (void)
{
}
-template <class SH, PR_AC_1>
-Handle_Thr_Acceptor<SH, PR_AC_2>::Handle_Thr_Acceptor (void)
+template <class SVH, PR_AC_1>
+Handle_Thr_Acceptor<SVH, PR_AC_2>::Handle_Thr_Acceptor (void)
: thr_flags_ (THR_DETACHED | THR_NEW_LWP)
{
}
-template <class SH, PR_AC_1> int
-Handle_Thr_Acceptor<SH, PR_AC_2>::info (char **strp,
+template <class SVH, PR_AC_1> int
+Handle_Thr_Acceptor<SVH, PR_AC_2>::info (char **strp,
size_t length) const
{
char buf[BUFSIZ];
@@ -54,8 +54,8 @@ Handle_Thr_Acceptor<SH, PR_AC_2>::info (char **strp,
return ACE_OS::strlen (buf);
}
-template <class SH, PR_AC_1> int
-Handle_Thr_Acceptor<SH, PR_AC_2>::init (int argc, char *argv[])
+template <class SVH, PR_AC_1> int
+Handle_Thr_Acceptor<SVH, PR_AC_2>::init (int argc, char *argv[])
{
ACE_INET_Addr local_addr (ACE_DEFAULT_THR_PORT);
int n_threads = ACE_DEFAULT_THREADS;
@@ -93,8 +93,8 @@ Handle_Thr_Acceptor<SH, PR_AC_2>::init (int argc, char *argv[])
return 0;
}
-template <class SH, PR_AC_1> int
-Handle_Thr_Acceptor<SH, PR_AC_2>::fini (void)
+template <class SVH, PR_AC_1> int
+Handle_Thr_Acceptor<SVH, PR_AC_2>::fini (void)
{
return ACE_Reactor::instance ()->remove_handler
(this, ACE_Event_Handler::ACCEPT_MASK);
@@ -161,7 +161,7 @@ CLI_Stream<PR_ST_2>::svc (void)
return 0;
}
-#undef SH
+#undef SVH
#undef PR_AC_1
#undef PR_AC_2
#undef PR_ST_1
diff --git a/examples/Connection/non_blocking/CPP-acceptor.cpp b/examples/Connection/non_blocking/CPP-acceptor.cpp
index fff8c2c1f6f..9e47943cc4d 100644
--- a/examples/Connection/non_blocking/CPP-acceptor.cpp
+++ b/examples/Connection/non_blocking/CPP-acceptor.cpp
@@ -14,7 +14,7 @@ ACE_RCSID(non_blocking, CPP_acceptor, "$Id$")
#define PR_AC_1 ACE_PEER_ACCEPTOR_1
#define PR_AC_2 ACE_PEER_ACCEPTOR_2
#define PR_AD ACE_PEER_STREAM_ADDR
-#define SH SVC_HANDLER
+#define SVH SVC_HANDLER
template <PR_ST_1>
Svc_Handler<PR_ST_2>::Svc_Handler (ACE_Reactor *r)
@@ -104,8 +104,8 @@ Svc_Handler<PR_ST_2>::handle_timeout (const ACE_Time_Value &,
return 0;
}
-template <class SH, PR_AC_1> int
-IPC_Server<SH, PR_AC_2>::init (int argc, char *argv[])
+template <class SVH, PR_AC_1> int
+IPC_Server<SVH, PR_AC_2>::init (int argc, char *argv[])
{
const char *local_addr = argc > 1
? argv[1]
@@ -157,25 +157,25 @@ IPC_Server<SH, PR_AC_2>::init (int argc, char *argv[])
return 0;
}
-template <class SH, PR_AC_1>
-IPC_Server<SH, PR_AC_2>::IPC_Server (void)
+template <class SVH, PR_AC_1>
+IPC_Server<SVH, PR_AC_2>::IPC_Server (void)
: done_handler_ (ACE_Sig_Handler_Ex (ACE_Reactor::end_event_loop))
{
}
-template <class SH, PR_AC_1> int
-IPC_Server<SH, PR_AC_2>::fini (void)
+template <class SVH, PR_AC_1> int
+IPC_Server<SVH, PR_AC_2>::fini (void)
{
return 0;
}
-template <class SH, PR_AC_1>
-IPC_Server<SH, PR_AC_2>::~IPC_Server (void)
+template <class SVH, PR_AC_1>
+IPC_Server<SVH, PR_AC_2>::~IPC_Server (void)
{
}
-template <class SH, PR_AC_1> int
-IPC_Server<SH, PR_AC_2>::handle_close (ACE_HANDLE handle,
+template <class SVH, PR_AC_1> int
+IPC_Server<SVH, PR_AC_2>::handle_close (ACE_HANDLE handle,
ACE_Reactor_Mask mask)
{
ACE_UNUSED_ARG (handle);
@@ -188,8 +188,8 @@ IPC_Server<SH, PR_AC_2>::handle_close (ACE_HANDLE handle,
// Run the interative service.
-template <class SH, PR_AC_1> int
-IPC_Server<SH, PR_AC_2>::svc (void)
+template <class SVH, PR_AC_1> int
+IPC_Server<SVH, PR_AC_2>::svc (void)
{
char buf[BUFSIZ];
@@ -209,9 +209,9 @@ IPC_Server<SH, PR_AC_2>::svc (void)
while (ACE_Reactor::event_loop_done () == 0)
{
- SH sh (this->reactor ());
+ SVH sh (this->reactor ());
- // Create a new <SH> endpoint, which performs all processing in
+ // Create a new <SVH> endpoint, which performs all processing in
// its <open> method (note no automatic restart if errno ==
// EINTR).
@@ -232,7 +232,7 @@ IPC_Server<SH, PR_AC_2>::svc (void)
this->acceptor ().get_handle ()));
}
// <SH>'s destructor closes the stream implicitly but the
// listening endpoint stays open.
}
@@ -245,5 +245,5 @@ IPC_Server<SH, PR_AC_2>::svc (void)
#undef PR_AC_1
#undef PR_AC_2
#undef PR_AD
-#undef SH
+#undef SVH
#endif /* CPP_ACCEPTOR_C */
@@ -232,7 +232,7 @@ IPC_Server<SH, PR_AC_2>::svc (void)
this->acceptor ().get_handle ()));
}
- // <SH>'s destructor closes the stream implicitly but the
+ // <SVH>'s destructor closes the stream implicitly but the
// listening endpoint stays open.
}